

set -ex



test -L $PREFIX/lib/libcupti.so.12
test -L $PREFIX/lib/libcupti.so.2024.2.0
test -L $PREFIX/targets/sbsa-linux/lib/libcupti.so.12
test -f $PREFIX/targets/sbsa-linux/lib/libcupti.so.2024.2.0
exit 0
